##  Configuring Collibra Integration
Admins can configure Collibra integration in the administration area by providing the credentials needed to connect with their Collibra instance. On a high level, it includes the following steps:
  1. [Setting Up Authentication](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275969c97a441014871dbb6ef0e0baef__setting_up_authentication).
  2. [Mapping conceptual data layer from Collibra to SAP LeanIX](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of the conceptual data layer from Collibra to the SAP LeanIX data object fact sheet, including assets, fields, responsibilities, and relations.").
  3. [Mapping fact sheet from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of application, business capability, and interface fact sheets from SAP LeanIX to Collibra to synchronize fields and subscriptions.").
  4. [Mapping relations from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of relations between fact sheets to the relation between assets to enhance data governance and lineage tracking.").
  5. [Trigger Synchronization](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275969c97a441014871dbb6ef0e0baef__trigger_synchronization).


To begin configuring Collibra integration:
  1. In the Administrationarea, select Integrations.
  2. Click Add integrations. All available integrations are shown on the resulting page.
  3. Against Collibra, click Configure.
  4. Set up the authentication by providing either Basic Auth or OAuth 2.0 credentials, as described below.
